@@ -3,7 +3,8 @@ import pkg_resources
 from . import physics, tutorial
 from .core import codes, data, remo_ds
 from .core.cal import parse_absolute_time, parse_dates
-from .core.domain import domain_info, remo_domain
+from .core.conventions import output_pattern
+from .core.domain import domain_info, magic_number, magic_numbers, remo_domain
 from .core.remo_ds import open_remo_dataset, preprocess, update_meta_info
 from .tables import domains, vc
 
@@ -26,9 +27,11 @@ __all__ = [
     "remo_domain",
     "open_remo_dataset",
     "preprocess",
+    "magic_number",
+    "magic_numbers",
     "update_meta_info",
     "domains",
     "vc",
-    "version",
+    "output_pattern",
     "",
 ]
