@@ -1,5 +1,6 @@
 import os
 
+import cf_xarray as cfxr  # noqa
 import cordex as cx
 import numpy as np
 import xarray as xr
@@ -18,6 +19,7 @@ from .core import (
     interpolate_horizontal,
     interpolate_horizontal_remo,
     interpolate_vertical,
+    intersect,
     intersect_regional,
     pbl_index,
     pressure_correction_em,
@@ -26,13 +28,26 @@ from .core import (
     rotate_uv,
 )
 
+# from pyremo.core.remo_ds import update_meta_info
+
+
 xr.set_options(keep_attrs=True)
 
 
 # variables that should have a mask with fill values
 fillvars = ["TSW", "SEAICE", "TSI"]
 
-vcs = ["hyai", "hybi", "hyam", "hybm", "akgm", "bkgm", "ak", "bk"]
+vcs = [
+    "hyai",
+    "hybi",
+    "hyam",
+    "hybm",
+    "akgm",
+    "bkgm",
+    "ak",
+    "bk",
+    "rotated_latitude_longitude",
+]
 
 
 def get_filename(date, expid="000000", template=None):
@@ -74,11 +89,11 @@ def to_netcdf(
                 ds[var].encoding["_FillValue"] = None
         dsets.append(ds)
     # dsets = [dset.expand_dims('time') for dset in datasets]
-    xr.save_mfdataset(dsets, paths, **kwargs)
-    if tempfiles is not None:
-        for f in tempfiles:
-            os.remove(f)
-    return paths
+    return xr.save_mfdataset(dsets, paths, **kwargs)
+    # if tempfiles is not None:
+    #    for f in tempfiles:
+    #        os.remove(f)
+    # return paths
 
 
 def to_tar(files, tar_file, mode="w"):
@@ -136,20 +151,26 @@ def remap(gds, domain_info, vc, surflib):
         `TSW`, `TSI` and `SEAICE`.
 
     """
+    # rename vertical coordinate of input to avoid conflict with output lev
+    gds = gds.copy()
+    gds = gds.rename({gds.cf["vertical"].name: lev_input})
 
-    #   'U'     , UR       , code=131, adims=(/IE,JE,KE, 2/), leveltype=110, kake=(/1  ,KE /), ntime=2, arakawa=ARAKAWA_RIGHT)
-    #   CALL add(BOUNDARY_TABLE, 'V'     , VR       , code=132, adims=(/IE,JE,KE, 2/), leveltype=110, kake=(/1  ,KE /), ntime=2, arakawa=ARAKAWA_TOP)
-    #   CALL add(BOUNDARY_TABLE, 'T'     , TR       , code=130, adims=(/IE,JE,KE, 2/), leveltype=110, kake=(/1  ,KE /), ntime=2)
-    #   CALL add(BOUNDARY_TABLE, 'QD'    , QDR      , code=133, adims=(/IE,JE,KE, 2/), leveltype=110, kake=(/1  ,KE /), ntime=2)
-    #   CALL add(BOUNDARY_TABLE, 'QW'    , QWR      , code=153, adims=(/IE,JE,KE, 2/), leveltype=110, kake=(/1  ,KE /), ntime=2)
-    #   CALL add(BOUNDARY_TABLE, 'PS'    , PSR      , code=134, adims=(/IE,JE, 2/)   , leveltype=1  , ntime=2)
-    #   CALL add(BOUNDARY_TABLE, 'QDBL'  , QDBLR    , code=84 , adims=(/IE,JE, 2/)   , leveltype=1  , ntime=2)
-    #   CALL add(BOUNDARY_TABLE, 'TSW'   , TSWECHR  , code=55 , adims=(/IE,JE, 2/)   , leveltype=1  , ntime=2)
-
-    #   CALL add(BOUNDARY_TABLE, 'TSI'   , TSIECHR  , code=56 , adims=(/IE,JE, 2/)   , leveltype=1  , ntime=2)
-    #   CALL add(BOUNDARY_TABLE, 'SEAICE'
-
-    # curvilinear coordinaetes
+    # if "clw" in gds:
+    #    gds["clw"] = gds.clw.clip(min=0.0)
+    # invalid = (gds.hus <= 0.0) | (gds.hus > 1.0) | (gds.clw > 1)
+    # gds["hus"] = xr.where(invalid, 0.0, gds.hus)
+    # gds["clw"] = xr.where(invalid, 0.0, gds.clw)
+    # DO ij = 1, IJGM
+    # QWGm(ij, k) = MAX(0.0_DP, QWGm(ij, k))
+    # IF ( QDGm(ij, k)<=0.0_DP ) THEN
+    #   QDGm(ij, k) = 0.0_DP
+    #   QWGm(ij, k) = 0.0_DP
+    # END IF
+    # IF ( QDGm(ij, k)>1.0_DP .OR. QWGm(ij, k)>1.0_DP ) THEN
+    #   QDGm(ij, k) = 0.0_DP
+    #   QWGm(ij, k) = 0.0_DP
+    # END IF
+    # END DO
 
     # remove time dimension if there is one
     fibem = surflib.FIB.squeeze(drop=True) * const.grav_const
@@ -159,15 +180,32 @@ def remap(gds, domain_info, vc, surflib):
     # broadcast 1d global coordinates
     lamgm, phigm = broadcast_coords(gds)
 
-    # horizontal interpolation
-    tge = interpolate_horizontal(gds.ta, lamem, phiem, lamgm, phigm, "T")
-    psge = interpolate_horizontal(gds.ps, lamem, phiem, lamgm, phigm, "PS")
-    uge = interpolate_horizontal(gds.ua, lamem, phiem, lamgm, phigm, "U", 1)
-    uvge = interpolate_horizontal(gds.ua, lamem, phiem, lamgm, phigm, "U", 2)
-    vge = interpolate_horizontal(gds.va, lamem, phiem, lamgm, phigm, "V", 2)
-    vuge = interpolate_horizontal(gds.va, lamem, phiem, lamgm, phigm, "V", 1)
-    fibge = interpolate_horizontal(gds.orog, lamem, phiem, lamgm, phigm, "FIB")
+    # compute remap matrix
+    indii, indjj = intersect(lamgm, phigm, lamem, phiem)  # .compute()
 
+    # horizontal interpolation
+    tge = interpolate_horizontal(
+        gds.ta, lamem, phiem, lamgm, phigm, "T", indii=indii, indjj=indjj
+    )
+    psge = interpolate_horizontal(
+        gds.ps, lamem, phiem, lamgm, phigm, "PS", indii=indii, indjj=indjj
+    )
+    uge = interpolate_horizontal(
+        gds.ua, lamem, phiem, lamgm, phigm, "U", 1, indii=indii, indjj=indjj
+    )
+    uvge = interpolate_horizontal(
+        gds.ua, lamem, phiem, lamgm, phigm, "U", 2, indii=indii, indjj=indjj
+    )
+    vge = interpolate_horizontal(
+        gds.va, lamem, phiem, lamgm, phigm, "V", 2, indii=indii, indjj=indjj
+    )
+    vuge = interpolate_horizontal(
+        gds.va, lamem, phiem, lamgm, phigm, "V", 1, indii=indii, indjj=indjj
+    )
+    fibge = interpolate_horizontal(
+        gds.orog, lamem, phiem, lamgm, phigm, "FIB", indii=indii, indjj=indjj
+    )
+    # return uge, vge
     # geopotential
     #     if "time" in gds.hus.dims:
     #         hus = gds.hus.isel(time=0)
@@ -186,22 +224,27 @@ def remap(gds, domain_info, vc, surflib):
         gds.orog, gds.ta, gds.hus, gds.ps, gds.akgm, gds.bkgm
     )  # .squeeze(drop=True)
 
-    ficge = interpolate_horizontal(ficgm, lamem, phiem, lamgm, phigm, "FIC")
+    ficge = interpolate_horizontal(
+        ficgm, lamem, phiem, lamgm, phigm, "FIC", indii=indii, indjj=indjj
+    )
 
     if "clw" in gds:
         # if False:
         arfgm = relative_humidity(gds.hus, gds.ta, gds.ps, gds.akgm, gds.bkgm, gds.clw)
     else:
         arfgm = relative_humidity(gds.hus, gds.ta, gds.ps, gds.akgm, gds.bkgm)
-    arfge = interpolate_horizontal(arfgm, lamem, phiem, lamgm, phigm, "AREL HUM")
-
+    arfge = interpolate_horizontal(
+        arfgm, lamem, phiem, lamgm, phigm, "AREL HUM", indii=indii, indjj=indjj
+    )
+    # return arfge
     # wind vector rotation
     uge_rot, vge_rot = rotate_uv(
         uge, vge, uvge, vuge, lamem, phiem, domain_info["pollon"], domain_info["pollat"]
     )
-
+    # return uge_rot, vge_rot
     # first pressure correction
     kpbl = pbl_index(gds.akgm, gds.bkgm)
+
     ps1em = pressure_correction_em(
         psge, tge, arfge, fibge, fibem, gds.akgm, gds.bkgm, kpbl
     )
@@ -211,28 +254,29 @@ def remap(gds, domain_info, vc, surflib):
     bkhgm = 0.5 * (gds.bkgm[:-1] + gds.bkgm[1:])
 
     akbkem = get_akbkem(vc)
+    ptop = akbkem.ak[0]
 
     tem = interpolate_vertical(
-        tge, psge, ps1em, akhgm, bkhgm, akbkem.akh, akbkem.bkh, "T", kpbl
+        tge, psge, ps1em, akhgm, bkhgm, akbkem.akh, akbkem.bkh, "T", kpbl, ptop=ptop
     )
 
     arfem = interpolate_vertical(
-        arfge, psge, ps1em, akhgm, bkhgm, akbkem.akh, akbkem.bkh, "RF", kpbl
+        arfge, psge, ps1em, akhgm, bkhgm, akbkem.akh, akbkem.bkh, "RF", kpbl, ptop=ptop
     )
-
+    # return arfem
     # second pressure correction and vertical interpolation of wind
     psem = pressure_correction_ge(ps1em, tem, arfem, ficge, fibem, akbkem.ak, akbkem.bk)
     psem.name = "PS"
 
     uem = interpolate_vertical(
-        uge_rot, psge, psem, akhgm, bkhgm, akbkem.akh, akbkem.bkh, "U", kpbl
+        uge_rot, psge, psem, akhgm, bkhgm, akbkem.akh, akbkem.bkh, "U", kpbl, ptop=ptop
     )
     vem = interpolate_vertical(
-        vge_rot, psge, psem, akhgm, bkhgm, akbkem.akh, akbkem.bkh, "V", kpbl
+        vge_rot, psge, psem, akhgm, bkhgm, akbkem.akh, akbkem.bkh, "V", kpbl, ptop=ptop
     )
 
     # correct wind with potential divergence
-    philuem = domain_info["ll_lon"]
+    philuem = domain_info["ll_lat"]
     dlamem = domain_info["dlon"]
     dphiem = domain_info["dlat"]
 
@@ -246,7 +290,8 @@ def remap(gds, domain_info, vc, surflib):
         phiem,
         lamgm,
         phigm,
-        blagm=np.around(gds.sftlf),
+        # blagm=np.around(gds.sftlf),
+        blagm=xr.where(gds.tos.isnull(), 1.0, 0.0),
         blaem=surflib.BLA.squeeze(drop=True),
     )
 
@@ -286,6 +331,7 @@ def remap(gds, domain_info, vc, surflib):
     ads.attrs = gds.attrs
 
     ads.attrs["history"] = "preprocessing with pyremo = {}".format(pr.__version__)
+    ads.attrs["CORDEX_domain"] = domain_info.get("short_name", "no name")
 
     ads = update_attrs(ads)
 
@@ -294,7 +340,14 @@ def remap(gds, domain_info, vc, surflib):
 
 
 def remap_remo(
-    tds, domain_info_em, domain_info_hm, vc, surflib, initial=False, lice=None
+    tds,
+    domain_info_em,
+    domain_info_hm,
+    vc,
+    surflib,
+    initial=False,
+    lice=None,
+    uvcor=True,
 ):
     """remapping workflow for double nesting
 
@@ -317,6 +370,8 @@ def remap_remo(
         orography ``FIB``.
     initial:
         If ``True``, add static and dynamic fields for initial conditions.
+    uvcor: bool
+        Do the u,v correction.
 
     Returns
     -------
@@ -328,10 +383,13 @@ def remap_remo(
     """
     # check if we have to derive seaice from tsw
     has_seaice = "SEAICE" in tds
+    if has_seaice is True:
+        tds["SEAICE"] = tds.SEAICE.fillna(0.0)
     if lice is None:
         lice = "SEAICE" not in tds
     # rename coords so they dont conflict with hm coords
-    tds = tds.copy().rename({"rlon": "rlon_em", "rlat": "rlat_em", "lev": lev_input})
+    # tds = tds.copy().rename({"rlon": "rlon_em", "rlat": "rlat_em", "lev": lev_input})
+    tds = tds.rename({"rlon": "rlon_em", "rlat": "rlat_em", "lev": lev_input})
     grid = get_grid(domain_info_hm)
 
     # curvilinear coordinaetes
@@ -366,7 +424,8 @@ def remap_remo(
     # qdeh = interpolate_horizontal_remo(tds.QD, indemi, indemj, dxemhm, dyemhm, "QD")
     fibeh = interpolate_horizontal_remo(tds.FIB, indemi, indemj, dxemhm, dyemhm, "FIB")
 
-    if has_seaice:
+    if has_seaice is True and lice is False:
+        tds["SEAICE"] = tds.SEAICE.fillna(0.0)
         siceem = tds.SEAICE
         sicehm = interp_horiz_remo_cm(
             tds.SEAICE,
@@ -382,9 +441,11 @@ def remap_remo(
             lamhm,
             "SICE",
         )
+        sicehm.name = "SEAICE"
     else:
-        sicehm = None
+        # sicehm = None
         siceem = None
+        sicehm = None
 
     tsweh = interp_horiz_remo_cm(
         tds.TSW,
@@ -422,6 +483,9 @@ def remap_remo(
         sicehm,
     )
 
+    if lice is True:
+        sicehm = physics.seaice(tsweh)
+
     if initial is True:
         tds = addem_remo(tds)
         soil = remap_soil(
@@ -467,14 +531,327 @@ def remap_remo(
     # dakem = tds.hyai[1:] - tds.hyai[:-1]
     # dbkem = tds.hybi[1:] - tds.hybi[:-1]
     akbkhm = get_akbkem(vc)
+    ptop = akbkhm.ak[0]
 
     thm = interpolate_vertical(
-        teh, pseh, ps1hm, akhem, bkhem, akbkhm.akh, akbkhm.bkh, "T", kpbl
+        teh, pseh, ps1hm, akhem, bkhem, akbkhm.akh, akbkhm.bkh, "T", kpbl, ptop=ptop
     )
     # return thm
     # return teh,thm, pseh, ps1hm
     # return akhem, bkhem, akbkhm.akh, akbkhm.bkh
 
+    arfhm = interpolate_vertical(
+        arfeh, pseh, ps1hm, akhem, bkhem, akbkhm.akh, akbkhm.bkh, "RF", kpbl, ptop=ptop
+    )
+
+    # second pressure correction and vertical interpolation of wind
+    pshm = pressure_correction_ge(ps1hm, thm, arfhm, ficeh, fibhm, akbkhm.ak, akbkhm.bk)
+    pshm.name = "PS"
+    # return ps1hm, pshm, thm, arfhm, ficeh, fibeh
+    # return pseh, pshm
+    # pseh_u = pseh.interp(rlon=pseh.rlon+0.5*0.0275, method='linear', kwargs={"fill_value": "extrapolate"})
+    # pshm_u = pshm.interp(rlon=pshm.rlon+0.5*0.0275, method='linear', kwargs={"fill_value": "extrapolate"})
+    # pseh_u[:,-1,:] = pseh[:,-1,:]
+    # pshm_u[:,-1,:] = pshm[:,-1,:]
+    uhm = interpolate_vertical(
+        ueh,
+        pseh.interp(
+            rlon=pseh.rlon + 0.5 * domain_info_hm["dlon"],
+            method="linear",
+            kwargs={"fill_value": "extrapolate"},
+        ),
+        pshm.interp(
+            rlon=pshm.rlon + 0.5 * domain_info_hm["dlon"],
+            method="linear",
+            kwargs={"fill_value": "extrapolate"},
+        ),
+        # pseh,
+        # pshm,
+        akhem,
+        bkhem,
+        akbkhm.akh,
+        akbkhm.bkh,
+        "U",
+        kpbl,
+        ptop=ptop,
+    )
+    # pseh_v = pseh.interp(rlat=pseh.rlat+0.5*0.0275, method='linear', kwargs={"fill_value": "extrapolate"})
+    # pshm_v = pshm.interp(rlat=pshm.rlat+0.5*0.0275, method='linear', kwargs={"fill_value": "extrapolate"})
+    # pseh_v[:,:,-1] = pseh[:,:,-1]
+    # pshm_v[:,:,-1] = pshm[:,:,-1]
+    vhm = interpolate_vertical(
+        veh,
+        pseh.interp(
+            rlat=pseh.rlat + 0.5 * domain_info_hm["dlat"],
+            method="linear",
+            kwargs={"fill_value": "extrapolate"},
+        ),
+        pshm.interp(
+            rlat=pshm.rlat + 0.5 * domain_info_hm["dlat"],
+            method="linear",
+            kwargs={"fill_value": "extrapolate"},
+        ),
+        # pseh_v,
+        # pshm_v,
+        akhem,
+        bkhem,
+        akbkhm.akh,
+        akbkhm.bkh,
+        "V",
+        kpbl,
+        ptop=ptop,
+    )
+
+    philuhm = domain_info_hm["ll_lon"]
+    dlamhm = domain_info_hm["dlon"]
+    dphihm = domain_info_hm["dlat"]
+
+    if uvcor is True:
+        uhm_corr, vhm_corr = correct_uv(
+            uhm, vhm, pshm, akbkhm.ak, akbkhm.bk, lamhm, phihm, philuhm, dlamhm, dphihm
+        )
+    else:
+        uhm_corr = uhm
+        vhm_corr = vhm
+
+    water_content = physics.water_content(thm, arfhm, pshm, akbkhm.akh, akbkhm.bkh)
+    # tsi = physics.tsi(tsw)
+
+    blaem = (np.around(tds.BLA),)
+    blahm = surflib.BLA.squeeze(drop=True)
+    phiem = tds.PHI.squeeze(drop=True)
+    lamem = tds.RLA.squeeze(drop=True)
+
+    ads = xr.merge(
+        [
+            thm,
+            uhm_corr,
+            vhm_corr,
+            pshm,
+            arfhm,
+            water_content,
+            pseh,
+            tsweh,
+            tsieh,
+            sicehm,
+            soil,
+            akbkhm,
+        ]
+    )
+
+    ads = ads.sel(rlon=grid.rlon, rlat=grid.rlat, method="nearest")
+    ads["rlon"] = grid.rlon
+    ads["rlat"] = grid.rlat
+
+    ads = xr.merge([ads, grid])
+
+    # rename for remo to recognize
+    ads = ads.rename({"ak": "hyai", "bk": "hybi", "akh": "hyam", "bkh": "hybm"})
+
+    if initial is True:
+        ads = add_surflib(ads, surflib)
+        ads = update_soil_temperatures(ads)
+        ads["GLAC"] = xr.where(ads.SN > 9.1, 1.0, 0.0)
+
+    ads = update_attrs(ads)
+
+    # ads = update_meta_info(ads)
+    # set global attributes
+    ads.attrs = tds.attrs
+
+    ads.attrs["history"] = "preprocessing with pyremo = {}".format(pr.__version__)
+
+    # transpose to remo convention
+    return ads.transpose(..., "lev", "rlat", "rlon")
+
+    # return uhm_corr
+    # return xr.merge([thm, pshm, uhm_corr, vhm_corr, qdhm, fibeh, ficeh, arfeh, ps1hm])
+
+
+def remap_remo2(
+    tds, domain_info_em, domain_info_hm, vc, surflib, initial=False, lice=None
+):
+    """remapping workflow for double nesting
+
+    This function should be similar to the ones in the
+    legacy fortran preprocessor intorg.
+
+    Parameters
+    ----------
+    tds : xarray.Dataset
+        REMO output t-file containing 3D atmospheric and 2D soil fields.
+
+    domain_info_hm : dict
+        A dictionary containing the domain information of the target domain.
+
+    vc : pandas.DataFrame
+        A table with the vertical coordinate coefficients ``ak`` and ``bk``.
+
+    surflib : xarray.Dataset
+        The surface library containing the target grid land sea mask ``BLA`` and
+        orography ``FIB``.
+    initial:
+        If ``True``, add static and dynamic fields for initial conditions.
+
+    Returns
+    -------
+    Forcing Dataset : xarray.Dataset
+        Dataset containing the forcing data interpolated to the
+        target domain. The dynamic variables include at least: ``T``, ``U``, ``V``, ``PS``, ``QD``,
+        ``QW``, ``QDBL``, ``TSW``, ``TSI`` and ``SEAICE``.
+
+    """
+
+    # check if we have to derive seaice from tsw
+    has_seaice = "SEAICE" in tds
+    if lice is None:
+        lice = "SEAICE" not in tds
+    # rename coords so they dont conflict with hm coords
+    # tds = tds.copy().rename({"rlon": "rlon_em", "rlat": "rlat_em", "lev": lev_input})
+    tds = tds.rename({"rlon": "rlon_em", "rlat": "rlat_em", "lev": lev_input})
+    grid = get_grid(domain_info_hm)
+
+    # curvilinear coordinaetes
+    # remove time dimension if there is one
+    fibhm = surflib.FIB.squeeze(drop=True) * const.grav_const
+    tds["FIB"] = tds.FIB * const.grav_const
+
+    blaem = tds.BLA
+    blahm = surflib.BLA.squeeze(drop=True)
+    phiem = tds.PHI.squeeze(drop=True)
+    lamem = tds.RLA.squeeze(drop=True)
+
+    lamhm, phihm = geo_coords(domain_info_hm, fibhm.rlon, fibhm.rlat)
+    # lamhm = lamhm.isel(pos=0).squeeze(drop=True)
+    # phihm = phihm.isel(pos=0).squeeze(drop=True)
+    # return lamhm, phihm
+    indemi, indemj, dxemhm, dyemhm = intersect_regional(domain_info_em, domain_info_hm)
+    indemi = indemi.assign_coords(rlon=surflib.rlon, rlat=surflib.rlat)
+    indemj = indemj.assign_coords(rlon=surflib.rlon, rlat=surflib.rlat)
+    dxemhm = dxemhm.assign_coords(rlon=surflib.rlon, rlat=surflib.rlat)
+    dyemhm = dyemhm.assign_coords(rlon=surflib.rlon, rlat=surflib.rlat)
+
+    # horizontal interpolation
+    teh = interpolate_horizontal_remo(tds.T, indemi, indemj, dxemhm, dyemhm, "T")
+    pseh = interpolate_horizontal_remo(tds.PS, indemi, indemj, dxemhm, dyemhm, "PS")
+    pseh.name = "PSEH"
+    ueh = interpolate_horizontal_remo(tds.U, indemi, indemj, dxemhm, dyemhm, "U", 1)
+    # uveh = interpolate_horizontal_remo(tds.U, indemi, indemj, dxemhm, dyemhm, "U", 2)
+    veh = interpolate_horizontal_remo(tds.V, indemi, indemj, dxemhm, dyemhm, "V", 4)
+    # vueh = interpolate_horizontal_remo(tds.V, indemi, indemj, dxemhm, dyemhm, "V", 3)
+    # qdeh = interpolate_horizontal_remo(tds.QD, indemi, indemj, dxemhm, dyemhm, "QD")
+    fibeh = interpolate_horizontal_remo(tds.FIB, indemi, indemj, dxemhm, dyemhm, "FIB")
+
+    if has_seaice is True and lice is False:
+        siceem = tds.SEAICE
+        sicehm = interp_horiz_remo_cm(
+            tds.SEAICE,
+            indemi,
+            indemj,
+            dxemhm,
+            dyemhm,
+            blaem,
+            blahm,
+            phiem,
+            lamem,
+            phihm,
+            lamhm,
+            "SICE",
+        )
+    else:
+        # sicehm = None
+        siceem = None
+        sicehm = None
+
+    tsweh = interp_horiz_remo_cm(
+        tds.TSW,
+        indemi,
+        indemj,
+        dxemhm,
+        dyemhm,
+        blaem,
+        blahm,
+        phiem,
+        lamem,
+        phihm,
+        lamhm,
+        "TSW",
+        lice,
+        siceem,
+        sicehm,
+    )
+
+    tsieh = interp_horiz_remo_cm(
+        tds.TSI,
+        indemi,
+        indemj,
+        dxemhm,
+        dyemhm,
+        blaem,
+        blahm,
+        phiem,
+        lamem,
+        phihm,
+        lamhm,
+        "TSI",
+        lice,
+        siceem,
+        sicehm,
+    )
+
+    if lice is True:
+        sicehm = physics.seaice(tsweh)
+
+    if initial is True:
+        tds = addem_remo(tds)
+        soil = remap_soil(
+            tds,
+            indemi,
+            indemj,
+            dxemhm,
+            dyemhm,
+            blaem,
+            blahm,
+            phiem,
+            lamem,
+            phihm,
+            lamhm,
+        )
+    else:
+        soil = xr.Dataset()
+
+    # return pseh
+    # return ueh
+    ficem = geopotential(
+        tds.FIB, tds.T, tds.QD, tds.PS, tds.hyai, tds.hybi
+    )  # .squeeze(drop=True)
+
+    ficeh = interpolate_horizontal_remo(ficem, indemi, indemj, dxemhm, dyemhm, "FIC")
+
+    arfem = relative_humidity(tds.QD, tds.T, tds.PS, tds.hyai, tds.hybi, tds.QW)
+    arfeh = interpolate_horizontal_remo(
+        arfem, indemi, indemj, dxemhm, dyemhm, "AREL HUM"
+    )
+
+    # first pressure correction
+    kpbl = pbl_index(tds.hyai, tds.hybi)
+
+    ps1hm = pressure_correction_em(
+        pseh, teh, arfeh, fibeh, fibhm, tds.hyai, tds.hybi, kpbl
+    )
+    ps1hm.name = "PS1HM"
+
+    # return pseh, teh, arfeh, fibeh, fibhm
+    # vertical interpolation
+    akhem = tds.hyam
+    bkhem = tds.hybm
+
+    akbkhm = get_akbkem(vc)
+
+    thm = interpolate_vertical(
+        teh, pseh, ps1hm, akhem, bkhem, akbkhm.akh, akbkhm.bkh, "T", kpbl
+    )
+
     arfhm = interpolate_vertical(
         arfeh, pseh, ps1hm, akhem, bkhem, akbkhm.akh, akbkhm.bkh, "RF", kpbl
     )
@@ -583,26 +960,36 @@ def remap_remo(
         ads = add_surflib(ads, surflib)
         ads = update_soil_temperatures(ads)
 
+    ads = update_attrs(ads)
+
+    # ads = update_meta_info(ads)
     # set global attributes
     ads.attrs = tds.attrs
 
     ads.attrs["history"] = "preprocessing with pyremo = {}".format(pr.__version__)
 
-    ads = update_attrs(ads)
-
     # transpose to remo convention
     return ads.transpose(..., "lev", "rlat", "rlon")
 
-    # return uhm_corr
-    # return xr.merge([thm, pshm, uhm_corr, vhm_corr, qdhm, fibeh, ficeh, arfeh, ps1hm])
-
 
 def remap_soil(
     tds, indemi, indemj, dxemhm, dyemhm, blaem, blahm, phiem, lamem, phihm, lamhm
 ):
     args = (indemi, indemj, dxemhm, dyemhm, blaem, blahm, phiem, lamem, phihm, lamhm)
 
-    remap_vars = ["DTPB", "TSL", "TSN", "TD3", "TD4", "TD5", "TD", "TDCL", "WS"]
+    remap_vars = [
+        "DTPB",
+        "TSL",
+        "TSN",
+        "TD3",
+        "TD4",
+        "TD5",
+        "TD",
+        "TDCL",
+        "WS",
+        "WL",
+        "SN",
+    ]
 
     # DTPB: TEMPERATUR - DIFFERENZ TP - TB HORIZONTAL INTERPOLIEREN
     def remap_var(varname):
@@ -672,9 +1059,13 @@ def addem_remo(tds):
 
 def add_surflib(ads, surflib):
     surflib = surflib.sel(rlon=surflib.rlon[1:-1], rlat=surflib.rlat[1:-1])
-    surflib["rlon"] = ads.rlon
-    surflib["rlat"] = ads.rlat
-    return xr.merge((ads, surflib.drop("rotated_pole")))
+    try:
+        surflib = surflib.drop("rotated_pole")
+    except Exception:
+        pass
+    return xr.merge(
+        (ads, surflib.squeeze(drop=True)), join="override", compat="override"
+    )
 
 
 def remap_sst(tos, lamem, phiem, lamgm, phigm, blagm, blaem):
@@ -707,13 +1098,13 @@ def update_attrs(ds):
         try:
             attrs = pr.codes.get_dict(var)
             da.attrs = {}
-            da.attrs["name"] = attrs["variable"]
-            da.attrs["code"] = attrs["code"]
-            da.attrs["description"] = attrs["description"]
-            da.attrs["units"] = attrs["units"]
-            # da.attrs['layer'] = attrs['layer']
+            for attr, value in attrs.items():
+                if value is not None:
+                    da.attrs[attr] = value
+
             da.attrs["grid_mapping"] = "rotated_latitude_longitude"
             da.attrs["coordinates"] = "lon lat"
+
         except Exception:
             pass
     return ds
