@@ -135,8 +135,8 @@ def compute_relative_pol(polphihm, pollamhm, polphiem, pollamem):
         # SK      POLGAM = - ZRPI18*ASIN(SIN(POLLAM*ZPIR18)  *
         # SK     1                     COS(POLPHIEM*ZPIR18)/COS(POLPHIHM*ZPIR18))
         # SK     2         - 180.0
-        zrpi18 = 57.2957795
-        zpir18 = 0.0174532925
+        zrpi18 = 57.2957795  # rad2deg
+        zpir18 = 0.0174532925  # deg2rad
         polgam = -zrpi18 * np.arcsin(
             np.cos(zpir18 * polphiem)
             * np.sin(zpir18 * (pollamhm - pollamem))
@@ -184,13 +184,24 @@ def intersect_regional(em, hm):
 
 
 def interpolate_horizontal(
-    da, lamem, phiem, lamgm, phigm, name=None, igr=None, blagm=None, blaem=None
+    da,
+    lamem,
+    phiem,
+    lamgm,
+    phigm,
+    name=None,
+    igr=None,
+    blagm=None,
+    blaem=None,
+    indii=None,
+    indjj=None,
 ):
     if name is None:
         name = da.name
     if igr is None:
         igr = 0
-    indii, indjj = intersect(lamgm, phigm, lamem, phiem)
+    if indii is None or indjj is None:
+        indii, indjj = intersect(lamgm, phigm, lamem, phiem)
     if blagm is None or blaem is None:
         return interp_horiz(
             da,
@@ -677,7 +688,7 @@ def map_sst(tos, ref_ds, resample="6H", regrid=True):
 
     if regrid:
         ref_ds["mask"] = ~(ref_ds.sftlf > 0)
-        tos["mask"] = ~tos.tos.isel(time=0).isnull()
+        tos["mask"] = ~tos.tos.isel(time=0).isnull().squeeze(drop=True)
         regridder = xe.Regridder(tos, ref_ds, "nearest_s2d")
         tos = regridder(tos.tos)
     tos.attrs.update(attrs)
@@ -874,13 +885,23 @@ def pressure_correction_em(psge, tge, arfge, fibge, fibem, akgm, bkgm, kpbl):
     return result
 
 
-def interpolate_vertical(xge, psge, ps1em, akhgm, bkhgm, akhem, bkhem, varname, kpbl):
+def interpolate_vertical(
+    xge, psge, ps1em, akhgm, bkhgm, akhem, bkhem, varname, kpbl, ptop=0.0
+):
     twoD_dims = list(horizontal_dims(psge))
     threeD_dims = list(horizontal_dims(psge)) + [lev_gm]
     input_core_dims = (
         [threeD_dims]
         + 2 * [twoD_dims]
-        + [[akhgm.dims[0]], [bkhgm.dims[0]], [akhem.dims[0]], [bkhem.dims[0]], [], []]
+        + [
+            [akhgm.dims[0]],
+            [bkhgm.dims[0]],
+            [akhem.dims[0]],
+            [bkhem.dims[0]],
+            [],
+            [],
+            [],
+        ]
     )
     output_core_dims = [twoD_dims + [akhem.dims[0]]]
     # print(output_core_dims)
@@ -895,6 +916,7 @@ def interpolate_vertical(xge, psge, ps1em, akhgm, bkhgm, akhem, bkhem, varname,
         bkhem,
         varname,
         kpbl,
+        ptop,
         input_core_dims=input_core_dims,  # list with one entry per arg
         output_core_dims=output_core_dims,  # returned data has 3 dimensions
         # exclude_dims=set(("index",)),
