@@ -1,6 +1,6 @@
 """default values for the command line interface
 """
 
-
-variables = ["T", "FI", "U", "V", "QD", "QW", "RELHUM"]
+# RELHUM not yet available
+variables = ["T", "FI", "U", "V", "QD", "QW"]
 plevs = [100, 200, 500, 850, 950]
